pub fn is_correct_length(msg_value: &SsbMessageValue) -> Result<bool>Expand description
Check that the length of the given message - when serialized as JSON - is less than 8192 UTF-16 code units.
pub fn is_correct_length(msg_value: &SsbMessageValue) -> Result<bool>Check that the length of the given message - when serialized as JSON - is less than 8192 UTF-16 code units.